@@ -262,7 +262,7 @@ static Status curlCodeToStatus(CURLcode code) {
       return Status(davix_scope_http_request(), StatusCode::OperationTimeout, ss.str());
     }
     default: {
-      return Status(davix_scope_http_request(), StatusCode::UnknowError, ss.str());
+      return Status(davix_scope_http_request(), StatusCode::UnknownError, ss.str());
     }
   }
 }
@@ -305,7 +305,6 @@ Status StandaloneCurlRequest::startRequest() {
   // Set request verb, target URL
   //----------------------------------------------------------------------------
   CURL* handle = _session->getHandle()->handle;
-  CURLM* mhandle = _session->getHandle()->mhandle;
 
   Uri uriCopy(_uri);
   uriCopy.httpizeProtocol();
@@ -360,7 +359,20 @@ Status StandaloneCurlRequest::startRequest() {
   //----------------------------------------------------------------------------
   // Set up client certificate
   //----------------------------------------------------------------------------
-  const X509Credential& clientCert = _params.getClientCertX509();
+  X509Credential clientCert = _params.getClientCertX509();
+  auto x509callback = _params.getClientCertCallbackX509();
+
+  if (x509callback.first) {
+    DavixError* err = NULL;
+    SessionInfo info;
+
+    x509callback.first(x509callback.second, info, &clientCert, &err);
+
+    if (err) {
+      DAVIX_SLOG(DAVIX_LOG_WARNING, DAVIX_LOG_HTTP, "Failed to load certificate via callback: {}", err->getErrMsg());
+      return Status(davix_scope_http_request(), err->getStatus(), "Failed to load certificate");
+    }
+  }
 
   std::string userCertificate;
   std::string userKey;
@@ -437,7 +449,7 @@ Status StandaloneCurlRequest::startRequest() {
 Status StandaloneCurlRequest::checkErrors() {
   CURLMsg *msg;
   int msgs_left = 0;
-  while(msg = curl_multi_info_read(_session->getHandle()->mhandle, &msgs_left)) {
+  while((msg = curl_multi_info_read(_session->getHandle()->mhandle, &msgs_left))) {
     if(msg->msg == CURLMSG_DONE && msg->data.result != CURLE_OK) {
       sessionError = curlCodeToStatus(msg->data.result);
       return sessionError;
@@ -597,7 +609,7 @@ void StandaloneCurlRequest::doNotReuseSession() {
 // Has the underlying session been used before?
 //------------------------------------------------------------------------------
 bool StandaloneCurlRequest::isRecycledSession() const {
-
+  return false;
 }
 
 //------------------------------------------------------------------------------
@@ -629,7 +641,7 @@ std::string StandaloneCurlRequest::getSessionError() const {
 // Block until all response headers have been received
 //------------------------------------------------------------------------------
 Status StandaloneCurlRequest::readResponseHeaders() {
-
+  return Status();
 }
 
 //------------------------------------------------------------------------------
@@ -646,4 +658,4 @@ void StandaloneCurlRequest::feedResponseHeader(const std::string &header) {
 }
 
 
-}
\ No newline at end of file
+}
